# PhoTrack
PhoTrack can get phonenumber location, timezone and service provider. You can use PhoTrack, to get essential informations about every Phonenumber. This Tool is just for educational and learning purposes!

## Installation

```
pip install photrack
```

## Usage 

Standalone:

```
py -m photrack
```

Module:

```
import photrack
>>> photrack.main()
# To start the default tool, updates to module using coming soon.
```